==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-64.js <==
dispMUA.arDispMUAAllocation["d"] =
{
  "do, or do not. there is no try." : [ "mixi.png" , "http://mixi.jp/" ] ,
  "desis & sertic :: facturacion" : [ "desis.png" , "http://www.desis.cl/" ] ,
  "dodo internet webmail server" : [ "dodo.png" , "http://www.dodo.com.au/" ] ,
  "datenkraft newsletter system" : [ "datenkraft.png" ] ,
  "dmc - www.dmcdeutschland.de" : [ "dmc.png" , "http://www.dmcdeutschland.de/" ] ,
  "digionline gmbh webweaver" : [ "digionline_webweaver.png" , "http://www.ww3ee.de/" ] ,
  "deutsche steuerverwaltung" : [ "elster.png" , "http://www.elster.de/" ] ,
  "domaincheck mailing list" : [ "domaincheck.png" ] ,
  "direct mail for mac os x" : [ "direct_mail_osx.png" ] ,
  "dreamhost mailing lists" : [ "dreamhost.png" , "http://www.dreamhost.com/" ] ,
  "doubleclick clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "doubleclick clickm@iler" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "de.tivano.mail.mailer" : [ "tivano_de.png" , "http://www.tivano.de/" ] ,
  "domain-offensive.de" : [ "domainoffensive.png" , "http://www.domain-offensive.de/" ] ,
  "donorware sendbulk" : [ "donorware.png" ] ,
  "dreamhost webmail" : [ "dreamhost.png" , "http://www.dreamhost.com/" ] ,
  "delano e-business" : [ "delano.png" ] ,
  "dynabyte webshop" : [ "dynabyte.png" , "http://www.dyna-byte.de/" ] ,
  "dumbonet systems" : [ "dumbonet.png" ] ,
  "directemail xtra" : [ "directmailxtra.png" ] ,
  "draco organizer" : [ "draco.png" , "http://www.dracosoftware.pl/" ] ,
  "divmod-quotient" : [ "divmod.png" ] ,
  "distributed.net" : [ "distributednet.png" ] ,
  "daum web mailer" : [ "daum_webmail.png" ] ,
  "datenbankmailer" : [ "datenbankmailer.png" , "http://www.datenbankmailer.de/" ] ,
  "dvise by tobit" : [ "tobit_david.png" , "http://www.tobit.com/" ] ,
  "dotnetopenmail" : [ "dotnetopenmail.png" ] ,
  "david by tobit" : [ "tobit_david.png" , "http://www.tobit.com/" ] ,
  "danger service" : [ "danger.png" ] ,
  "dacons mail.it" : [ "dacons_mail_it.png" , "http://www.dacons.net/fmplugins/mailit/" ] ,
  "dundas mailer" : [ "dundas.png" ] ,
  "domainfactory" : [ "domainfactory.png" ] ,
  "de.netlog.com" : [ "netlog_com.png" , "http://de.netlog.com/" ] ,
  "douhou@mail" : [ "douhou.png" , "http://www.netdeoshigoto.com/mail/" ] ,
  "directmail/" : [ "toolmaker_de.png" , "http://www.toolmaker.de/" ] ,
  "dialog-mail" : [ "dialog-mail.png" , "http://www.dialog-mail.com/" ] ,
  "devmail.net" : [ "devmailnet.png" ] ,
  "dsa-launch" : [ "dsa_launch.png" ] ,
  "discount24" : [ "discount24_de.png" , "http://www.discount24.de/" ] ,
  "dti tools" : [ "dti.png" , "http://dream.jp/option/tools/" ] ,
  "dtemapper" : [ "dtemapper.png" , "http://www.desis.cl/" ] ,
  "dreammail" : [ "dreammailer.png" ] ,
  "desknet's" : [ "desknet.png" ] ,
  "delosmail" : [ "delosmail.png" , "http://e-delos.com/" ] ,
  "datevmail" : [ "datev.png" , "http://www.datev.de/" ] ,
  "dada mail" : [ "dada_mail.png" ] ,
  "dovenews" : [ "dovenews.png" ] ,
  "dotclear" : [ "dotclear.png" ] ,
  "dmailweb" : [ "netwinsite.png" , "http://netwinsite.com/dmailweb/" ] ,
  "discuz!" : [ "discuz.png" , "http://www.discuz.com/" ] ,
  "di-php4" : [ "di_com_pl.png" , "http://www.di.com.pl/" ] ,
  "deskpro" : [ "deskpro.png" , "http://www.deskpro.com/" ] ,
  "desknow" : [ "desknow.png" ] ,
  "denshin" : [ "denshin.png" ] ,
  "dyndns" : [ "dyndns.png" ] ,
  "dtmail" : [ "dtmail.png" ] ,
  "dspwin" : [ "dspwin.png" , "http://www.dspwin.de/" ] ,
  "drupal" : [ "drupal.png" ] ,
  "dr.web" : [ "drweb.png" , "http://www.drweb-online.com/" ] ,
  "direto" : [ "direto.png" ] ,
  "datula" : [ "datula.png" ] ,
  "danaos" : [ "danaos.png" ] ,
  "dmail" : [ "netwinsite_dmail.png" , "http://netwinsite.com/dmail_first.htm" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-64.js <==
dispMUA.arDispMUAAllocation["d"] =
{
  "do, or do not. there is no try." : [ "mixi.png" , "http://mixi.jp/" ] ,
  "desis & sertic :: facturacion" : [ "desis.png" , "http://www.desis.cl/" ] ,
  "dodo internet webmail server" : [ "dodo.png" , "http://www.dodo.com.au/" ] ,
  "datenkraft newsletter system" : [ "datenkraft.png" ] ,
  "dmc - www.dmcdeutschland.de" : [ "dmc.png" , "http://www.dmcdeutschland.de/" ] ,
  "digionline gmbh webweaver" : [ "digionline_webweaver.png" , "http://www.ww3ee.de/" ] ,
  "deutsche steuerverwaltung" : [ "elster.png" , "http://www.elster.de/" ] ,
  "domaincheck mailing list" : [ "domaincheck.png" ] ,
  "direct mail for mac os x" : [ "direct_mail_osx.png" ] ,
  "dreamhost mailing lists" : [ "dreamhost.png" , "http://www.dreamhost.com/" ] ,
  "doubleclick clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "doubleclick clickm@iler" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "de.tivano.mail.mailer" : [ "tivano_de.png" , "http://www.tivano.de/" ] ,
  "domain-offensive.de" : [ "domainoffensive.png" , "http://www.domain-offensive.de/" ] ,
  "donorware sendbulk" : [ "donorware.png" ] ,
  "dreamhost webmail" : [ "dreamhost.png" , "http://www.dreamhost.com/" ] ,
  "delano e-business" : [ "delano.png" ] ,
  "dynabyte webshop" : [ "dynabyte.png" , "http://www.dyna-byte.de/" ] ,
  "dumbonet systems" : [ "dumbonet.png" ] ,
  "directemail xtra" : [ "directmailxtra.png" ] ,
  "draco organizer" : [ "draco.png" , "http://www.dracosoftware.pl/" ] ,
  "divmod-quotient" : [ "divmod.png" ] ,
  "distributed.net" : [ "distributednet.png" ] ,
  "daum web mailer" : [ "daum_webmail.png" ] ,
  "datenbankmailer" : [ "datenbankmailer.png" , "http://www.datenbankmailer.de/" ] ,
  "dvise by tobit" : [ "tobit_david.png" , "http://www.tobit.com/" ] ,
  "dotnetopenmail" : [ "dotnetopenmail.png" ] ,
  "david by tobit" : [ "tobit_david.png" , "http://www.tobit.com/" ] ,
  "danger service" : [ "danger.png" ] ,
  "dacons mail.it" : [ "dacons_mail_it.png" , "http://www.dacons.net/fmplugins/mailit/" ] ,
  "dundas mailer" : [ "dundas.png" ] ,
  "domainfactory" : [ "domainfactory.png" ] ,
  "de.netlog.com" : [ "netlog_com.png" , "http://de.netlog.com/" ] ,
  "douhou@mail" : [ "douhou.png" , "http://www.netdeoshigoto.com/mail/" ] ,
  "directmail/" : [ "toolmaker_de.png" , "http://www.toolmaker.de/" ] ,
  "dialog-mail" : [ "dialog-mail.png" , "http://www.dialog-mail.com/" ] ,
  "devmail.net" : [ "devmailnet.png" ] ,
  "dsa-launch" : [ "dsa_launch.png" ] ,
  "dotproject" : [ "dotproject.png" , "http://www.dotproject.net/" ] ,
  "discount24" : [ "discount24_de.png" , "http://www.discount24.de/" ] ,
  "dti tools" : [ "dti.png" , "http://dream.jp/option/tools/" ] ,
  "dtemapper" : [ "dtemapper.png" , "http://www.desis.cl/" ] ,
  "dreammail" : [ "dreammailer.png" ] ,
  "desknet's" : [ "desknet.png" ] ,
  "delosmail" : [ "delosmail.png" , "http://e-delos.com/" ] ,
  "datevmail" : [ "datev.png" , "http://www.datev.de/" ] ,
  "dada mail" : [ "dada_mail.png" ] ,
  "dovenews" : [ "dovenews.png" ] ,
  "dotclear" : [ "dotclear.png" ] ,
  "dmailweb" : [ "netwinsite.png" , "http://netwinsite.com/dmailweb/" ] ,
  "dell mfp" : [ "dell.png" , "http://www.dell.com/" ] ,
  "dls.net" : [ "dls_net.png" , "http://www.dls.net/" ] ,
  "discuz!" : [ "discuz.png" , "http://www.discuz.com/" ] ,
  "di-php4" : [ "di_com_pl.png" , "http://www.di.com.pl/" ] ,
  "deskpro" : [ "deskpro.png" , "http://www.deskpro.com/" ] ,
  "desknow" : [ "desknow.png" ] ,
  "denshin" : [ "denshin.png" ] ,
  "dyndns" : [ "dyndns.png" ] ,
  "dtmail" : [ "dtmail.png" ] ,
  "dspwin" : [ "dspwin.png" , "http://www.dspwin.de/" ] ,
  "drupal" : [ "drupal.png" ] ,
  "dr.web" : [ "drweb.png" , "http://www.drweb-online.com/" ] ,
  "discus" : [ "labrate.png" , "http://www.labrate.ru/discus/" ] ,
  "direto" : [ "direto.png" ] ,
  "dcmail" : [ "dcmail.png" , "http://www.dcmail.net/" ] ,
  "datula" : [ "datula.png" ] ,
  "danaos" : [ "danaos.png" ] ,
  "dmail" : [ "netwinsite_dmail.png" , "http://netwinsite.com/dmail_first.htm" ] ,
}
